SpanContext class abstract

Representation of the context of an individual span.

Implementers

Constructors

SpanContext()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRemote → bool
Whether this SpanContext represents an operation which originated from a remote source.
no setter
isValid → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spanId → SpanId
Get the ID of the span.
no setter
traceFlags → int
Get W3C trace context flags used in propagation represented by a one byte bitmap.
no setter
traceId → TraceId
Get the ID of the trace the span is a part of.
no setter
traceState → TraceState
Get the state of the entire trace.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited