SpanLink class

Constructors

SpanLink(SpanContext? _context, {List<Attribute>? attributes})

Properties

attributes → List<Attribute>
no setter
context → SpanContext?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited