Tracer class abstract

An interface for creating api.Spans and propagating context in-process.

Users may choose to use manual or automatic Context propagation. Because of that, this class offers APIs to facilitate both usages.

Constructors

Tracer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startSpan(String name, {Context? context, SpanKind? kind = api.SpanKind.client, List<Attribute>? attributes, List<SpanLink>? links, Int64? startTime}) → Span
Starts a new api.Span without setting it as the current span in this tracer's context.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited