SpanContext class

Representation of the context of the context of an individual span.

Implemented types

Constructors

SpanContext(TraceId _traceId, SpanId _spanId, int _traceFlags, TraceState _traceState)
Construct a SpanContext.
SpanContext.invalid()
Construct an invalid SpanContext.
SpanContext.remote(TraceId _traceId, SpanId _spanId, int _traceFlags, TraceState _traceState)
Construct a SpanContext representing an operation which originated from a remote source.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRemote → bool
Whether this SpanContext represents an operation which originated from a remote source.
no setteroverride
isValid → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spanId → SpanId
Get the ID of the span.
no setteroverride
traceFlags → int
Get W3C trace context flags used in propagation represented by a one byte bitmap.
no setteroverride
traceId → TraceId
Get the ID of the trace the span is a part of.
no setteroverride
traceState → TraceState
Get the state of the entire trace.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited